
  .jslider_round .jslider-bg i,
  .jslider_round .jslider-pointer
  { background-image: url(jslider.round.png); }

  .jslider_round .jslider-pointer { width: 17px; height: 17px; top: -6px; margin-left: -8px; }
