
  .jslider_round_plastic .jslider-bg i,
  .jslider_round_plastic .jslider-pointer
  { background-image: url(jslider.round.plastic.png); }

  .jslider_round_plastic .jslider-pointer { width: 18px; height: 18px; top: -7px; margin-left: -8px; }
