
/*#flexitopicsearchform label {display:block;} */

#flexitopicsearchform div {
  display:inline-block;
  margin:0 10px 10px 0;
  zoom:1;
}

#flexitopicsearchform div.jslider-bg {
  display:block;
  margin:0;
}

#flexitopicsearchform span.jslider {
    margin-top: 1em;
}

#flexitopicsearchform div.formHelp {
  display: none;
}

#flexitopicsearchform input.searchButton {
clear: both;
}


.flexigrid div.hDiv th {
line-height: 1em;
}

.flexigrid div.hDivBox table {
margin-bottom: 0 !important;
}

